@@ -36,7 +36,7 @@ if (!isGeneric("overlay"))
 	setGeneric("overlay", function(x, y, ...)
 		standardGeneric("overlay"))
 if (!isGeneric("over"))
-	setGeneric("over", function(x, y, returnList = FALSE, fn = NULL)
+	setGeneric("over", function(x, y, returnList = FALSE, fn = NULL, ...)
 		standardGeneric("over"))
 if (!isGeneric("plot"))
 	setGeneric("plot", function(x, y, ...)
